angular.module('starter.services', [])

.factory('AuthInterceptor', function ($rootScope, $q, AUTH_EVENTS) {
  return {
    responseError: function (response) {
      $rootScope.$broadcast({
        401: AUTH_EVENTS.notAuthenticated,
        403: AUTH_EVENTS.notAuthorized
      }[response.status], response);
      return $q.reject(response);
    }
  };
})
 
.config(function ($httpProvider) {
  $httpProvider.interceptors.push('AuthInterceptor');
})

.service('Loading', function($ionicLoading){
	this.show = function() {
		$ionicLoading.show({
			template: 'Cargando...',
		}).then(function(){
			console.log("The loading indicator is now displayed");
		});
	};
	
	this.hide = function(){
		$ionicLoading.hide().then(function(){
			console.log("The loading indicator is now hidden");
		});
	};
})

.service('Stats', function($http, $q, ApiEndpoint){
	this.actual = function(){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/historicas',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.pendiente = function(){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/pendientes',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.vencidos = function(){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/vencidos',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.caja = function(estado){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/caja/vencidos/'+estado,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.proyectados = function(){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/futuro',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.distribuidor_actual = function(id){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/distribuidor/'+id+'/historicas',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.distribuidor_pendiente = function(id){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/distribuidor/'+id+'/pendientes',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.distribuidor_vencidos = function(id){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/distribuidor/'+id+'/vencidos',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};

	this.distribuidor_proyectados = function(id){
		var dfd = $q.defer();
    
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'estadisticas/distribuidor/'+id+'/futuro',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
        
        return dfd.promise;
	};
})

.service('AuthService', function($q, $http, USER_ROLES, ApiEndpoint) {
	var LOCAL_TOKEN_KEY = 'token';
	var username = '';
	var isAuthenticated = false;
	var userCan = [];
	var role = '';
	var authToken;

	function loadUserCredentials() {
		var token = window.localStorage.getItem(LOCAL_TOKEN_KEY);
		if (token) {
		useCredentials(token);
		}
	}

	function storeUserCredentials(data) {
		window.localStorage.setItem(LOCAL_TOKEN_KEY, data.token);
		window.localStorage.setItem('public', data.public);
		window.localStorage.setItem('auth', JSON.stringify(data.permisos));
		useCredentials(data);
	}
	function useCredentials(data) {
		console.log(data);
		isAuthenticated = true;
		authToken = data.token;

		userCan = data.permisos;
		// Set the token as header for your requests!
		$http.defaults.headers.common['X-Auth-Token'] = data.token;
	}

	function destroyUserCredentials() {
		authToken = undefined;
		username = '';
		isAuthenticated = false;
		userCan = [];
		$http.defaults.headers.common['X-Auth-Token'] = undefined;
		window.localStorage.removeItem(LOCAL_TOKEN_KEY);
	}

	var login = function(usuario) {
		var dfd = $q.defer();
        
        if (usuario.username == '' || usuario.password == '')
            dfd.resolve({ status: 'error', msg: 'El usuario y contraseña son necesarios' });
        else {
			$http({
	            method: 'POST',
	            url: ApiEndpoint.url + 'login',
				headers: { Enviroment: usuario.enviroment }, 
	            data: { "usuario": usuario.username , "contra":  usuario.password }
        	})
            .success(function (data) {
				storeUserCredentials(data);
                dfd.resolve({ status: 'ok', data: data });
            })
            .error(function (errorData) {
               dfd.resolve(errorData);
            });
        }
        
        return dfd.promise;
	};

	var logout = function() {
		destroyUserCredentials();
	};

	var isAuthorized = function(state) {
		authorizedRoles = 'auth' in localStorage ? JSON.parse(localStorage.auth) : undefined;
		if (!angular.isArray(authorizedRoles)) {
		authorizedRoles = [authorizedRoles];
		}
		return (isAuthenticated && authorizedRoles.indexOf(state) !== -1);
	};

	loadUserCredentials();

	return {
		login: login,
		logout: logout,
		isAuthorized: isAuthorized,
		isAuthenticated: function() {return isAuthenticated;},
		username: function() {return username;},
		role: function() {return role;},
		userCan: function(){return userCan;}
	};
})

.service('Usuario', function($http, $q, ApiEndpoint){
	this.Login = function(usuario){
		var dfd = $q.defer();
        
        if (usuario.username == '' || usuario.password == '')
            dfd.resolve({ status: 'error', msg: 'El usuario y contraseña son necesarios' });
        else {
			$http({
	            method: 'POST',
	            url: ApiEndpoint.url + 'login',
				headers: { 'Enviroment': localStorage.enviroment },
	            data: { "usuario": usuario.username , "contra":  usuario.password }
        	})
            .success(function (data) {

                dfd.resolve({ status: 'ok', data: data });
            })
            .error(function (errorData) {
               dfd.resolve(errorData);
            });
        }
        
        return dfd.promise;
	};

	this.all = function(c){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'usuarios/' + c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        return dfd.promise;
	};
	
	this.count = function(){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'usuarios/contar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        return dfd.promise;
	};

	this.get = function(c){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'usuario/' + c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.save = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'new/usuario',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : c
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(c, i){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'usuario/' + i,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : c
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        return dfd.promise;
	};
})

.service('Cliente', function($http, $q, ApiEndpoint){
	this.all = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'clientes/' + c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.count = function(){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'clientes/contar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.get = function(cliente){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'cliente/' + cliente,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.save = function(cliente){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'new/cliente',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : cliente
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(cliente){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'cliente/' + cliente.cliente_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : cliente
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.search = function(q, p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'search/cliente/' + p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : q
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.getParents = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'clientes/parentesco' ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : c
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })	
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.getRealtedAddress = function(a){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'clientes/domicilio/similar' ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : a
		})
		.success(function (data) {
            dfd.resolve(data);
        })	
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.setParent = function(p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'clientes/parentesco/confirmar' ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : p
		})
		.success(function (data) {
            dfd.resolve(data);
        })	
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.contracts = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'cliente/' + c + '/contratos',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Distribuidor', function($http, $q, $filter, ApiEndpoint){
	this.restructure = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'distribuidor/' + c.distribuidor_id + '/reestructuracion',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.all = function(c, filter = 'all'){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'clientes/distribuidores/' + c + '/' + filter,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.count = function(c = 'all'){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'clientes/distribuidores/contar/' + c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.get = function(cliente){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'distribuidor/' + cliente,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			data.fecha_nacimiento = new Date(data.fecha_nacimiento+"T12:00:00Z");
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.save = function(d){
		console.log(d)
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'new/distribuidor',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(cliente){
		var dfd = $q.defer();
		console.log(cliente);
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidor/' + cliente.distribuidor_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : cliente
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.refUpdate = function(d){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidor/referencia/' + d.referencia_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};
	
	this.contracts = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'cliente/distribuidor/' + c + '/contratos',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.search = function(q, p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'search/distribuidor/' + p + '/ALL',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : q
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.pay = function(d,q){
		var dfd = $q.defer();
		f = q.fecha_realizada > q.fecha_programada ? $filter('date')(q.fecha_realizada, 'yyyy-MM-dd') : $filter('date')(q.fecha_programada, 'yyyy-MM-dd');
		
		q.fecha_realizada = $filter('date')(q.fecha_realizada, 'yyyy-MM-dd');
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'pagos/pagar/distribuidor/' + d + '/' + f,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : q
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	//PAGARES

	this.getPagares = function(p){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + "distribuidor/" + p + "/pagares",
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.doPagare = function(m, c){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + '/distribuidor/'+ c +'/new/pagare',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : {"monto" : m}
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.delPagare = function(d){
		var dfd = $q.defer();
		$http({
			method: 'DELETE',
			url: ApiEndpoint.url + 'distribuidor/borrar/pagare/'+d,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.getCanjearVale = function(f){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'search/distribuidor/referencia/' + f,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
        }).error(function (errorData) {
			console.log(errorData)
        });
        
        return dfd.promise;
	};

	this.getActive = function(f){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'distribuidores/corte/' + f,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};

	this.getCorte = function(i, d, f){
		console.log("contes");
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'distribuidor/' + d + '/corte/' + f + '/0' ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data, index: i });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};

	this.getRecibos = function(i, d, f){
		console.log("recibos");
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'distribuidor/' + d + '/recibo/cliente/' + f + '/0' ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data, index: i });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        return dfd.promise;
	};
	
	this.downloadCortes = function(d,f){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidores/cortes/descargar/'+f ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ data });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};

	this.downloadRecibos = function(d,f){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidores/recibo/cliente/descargar/'+f ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ data });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};

	this.printCortes = function(d,f){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidores/cortes/print/'+f ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ data });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};

	this.printRecibos = function(d,f){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'distribuidores/recibo/cliente//print/'+f ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ data });
        }).error(function (errorData) {
			dfd.reject(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Vales', function($http, $q, ApiEndpoint, $filter){
	this.save = function(d){
		console.log(d);
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'distribuidor/'+d.distribuidor_id+'/new/vales',
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			console.log("jalo")
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			console.log("nojalo")
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.del = function(d){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'vale/cancelar/' + d.referencia_id,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.due = function(c){
		var dfd = $q.defer();
		debugger
		c.fecha_realizada = c.fecha_realizada == null ? '-' : ( c.fecha_realizada instanceof Date ? $filter('date')(c.fecha_realizada, 'yyyy-MM-dd') : c.fecha_realizada.replaceAll('-', '/') );
		// c.fecha_programada = c.fecha_realizada < c.fecha_programada ? $filter('date')(c.fecha_realizada, 'yyyy-MM-dd') : $filter('date')(c.fecha_programada, 'yyyy-MM-dd');
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/pagar/' + c.target + '/' + c.id + '/' + c.fecha_programada + '/' + c.fecha_realizada,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.interes = function(canje){
		var dfd = $q.defer();

		if('producto' in canje){
			var p = canje.producto.producto_id;
			var z = canje.plazo_pagos.periodos_max;
		}else if(canje.montos.length > 0){
			var p = canje.producto_id;
			var z = canje.plazo_pagos.value;
		}else{
			var p = canje.producto_id;
			var z = canje.plazo_pagos;
		}
				
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/product/' + p + '/0/' + z,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.comision = function(c){
		var dfd = $q.defer();

		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/comision/' + c.producto_id + '/' + c.fecha_programada + '/' + ( c.fecha_realizada instanceof Date ? $filter('date')(c.fecha_realizada, 'yyyy-MM-dd') : c.fecha_realizada ),
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			data.comision = (parseFloat(data.comision)*100).toFixed(2);
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.count = function(product, query){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'vales/contar/' + product,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : {
				query: query
			}
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.search = function(product, page, query){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'vales/' + product + '/' + page,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : {
				query: query
			}
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.productos = function(product, distribuidor) {
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'distribuidor/' + distribuidor + '/montos/' + product,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	}
})

.service('Domicilio', function($http, $q, ApiEndpoint){
	this.all = function(c){
		var dfd = $q.defer();
		console.log(c);
		$http({
			method: 'GET',
			url: ApiEndpoint.url + c.current+'/'+c.id+'/direcciones/',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        return dfd.promise;
	};
	
	this.save = function(d){
		console.log(d);
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url = ApiEndpoint.url + (d.cliente_id ? 'cliente/' : 'distribuidor/')+id+'/new/direccion';
		$http({
			method: 'POST',
			url: url,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(d){
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url = ApiEndpoint.url + (d.cliente_id ? 'cliente/' : 'distribuidor/')+id+'/direccion/'+d.domicilio_id;
		console.log(url + "update");
		$http({
			method: 'POST',
			url: url,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.del = function(d){
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url = ApiEndpoint.url + (d.cliente_id ? 'cliente/' : 'distribuidor/')+id+'/direccion/'+d.domicilio_id;
		$http({
			method: 'DELETE',
			url: url,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.proxy = function(params){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'clientes/direccion/proxy/'+params.col+'/'+params.value,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve(data);
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Telefono', function($http, $q, ApiEndpoint){
	this.all = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'cliente/'+c+'/telefonos/',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.save = function(d){
		console.log(d);
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url = ApiEndpoint.url + 'cliente/'+id+'/new/telefono'
		console.log(id);
		$http({
			method: 'POST',
			url: url,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(d){
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url = ApiEndpoint.url + 'cliente/'+id+'/telefono/'+d.telefono_id;
		$http({
			method: 'POST',
			url: url,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.del = function(d){
		var dfd = $q.defer();
		var id = d.cliente_id ? d.cliente_id : d.distribuidor_id;
		var url =  ApiEndpoint.url + 'cliente/'+id+'/telefono/'+d.telefono_id;
		console.log(d);
		$http({
			method: 'DELETE',
			url: url,
			data: d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Producto', function($http, $q, ApiEndpoint){
	this.all = function(p){
		console.log(p)
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'productos/' + p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			console.log(data);
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	this.count = function(){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'productos/contar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	this.save = function(p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'new/producto',
			data : p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(p){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'producto/' +  p.producto_id ,
			data : p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.get = function(p){
		console.log(p);
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'producto/'+ p ,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.search = function(q, p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'search/producto/' + p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : q
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
		return dfd.promise;
	};
})

.service('Permiso', function($http, $q, ApiEndpoint){
	this.nuevo = function(permiso){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + '/usuario/' + permiso.usuario_id + '/permiso',
			data: permiso,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.eliminar = function(permiso){
		var dfd = $q.defer();
		
		$http({
			method: 'DELETE',
			url: ApiEndpoint.url + '/usuario/' + permiso.usuario_id + '/permiso',
			data: permiso,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Contrato', function($http, $q, ApiEndpoint, $filter){
	this.nuevo = function(contrato){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'new/contrato',
			data: contrato,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.update = function(contrato){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'contrato/'+contrato.contrato_id,
			data: contrato,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.get = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'contrato/' + c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			data.creacion = new Date(data.creacion);

			var date = data.primer_pago + new Date(data.primer_pago).getTimezoneOffset()*60000;
			data.primer_pago = data.primer_pago == '0' ? data.creacion : new Date(date);
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.cancel = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'contrato/' + c + '/cancelar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.restructure = function(c){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'new/contrato',
			data: c,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.all = function(t, p, q){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'contratos/' + t + '/' + p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data: {
				query: q
			}
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.count = function(t){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'contratos/' + t + '/contar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.due = function(c){
		var dfd = $q.defer();

		function formatDate(date) {
			if(typeof date !== 'undefined'){
				var d = new Date(date);
			}else{
				var d = new Date();
			}
			
			var  month = '' + (d.getMonth() + 1),
				day = '' + d.getDate(),
				year = d.getFullYear();
		
			if (month.length < 2) month = '0' + month;
			if (day.length < 2) day = '0' + day;
		
			return [year, month, day].join('-');
		}
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/pagar/' + c + '/' + formatDate(),
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.pay =function(c, q){
		var dfd = $q.defer();
		
		f = q.fecha_realizada > q.fecha_programada ? $filter('date')(q.fecha_realizada, 'yyyy-MM-dd') : $filter('date')(q.fecha_programada, 'yyyy-MM-dd');
		
		q.fecha_realizada = $filter('date')(q.fecha_realizada, 'yyyy-MM-dd');

		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/pagar/contrato/' + c + '/' + f,
			data : q,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.pastPay =function(c, p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/anteriores/' + c,
			data : p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Buro', function($http, $q, ApiEndpoint){
	this.infoCount = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'circulo_credito/clientes/info_faltante/count',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.infoAll = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'circulo_credito/clientes/info_faltante/all',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
	
	this.info = function(p){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'circulo_credito/clientes/info_faltante/'+p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('Credito', function(){
	//i=interes
	//v=monto
	//n=periodos
	//p=pagos
	
	this.pago = function(v,i,n){
		return (v*i)/(1-Math.pow((1+i),-n));
	};
	
	this.monto = function(i,n,p){
		return ((p*(1-Math.pow((1+i),-n)))/i);
	}
	
	this.periodos = function(v,i,p){
		return -(Math.log(1-(v*i/p))/Math.log(1+i));
	}
	
	this.intereses = function(v,i,p){
		return v*p*i/360;
	}
})

.service('Bitacora', function($http, $q, ApiEndpoint){
	this.nuevo = function(bitacora){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'bitacora/nueva',
			data: bitacora,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.borrar = function(id){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'bitacora/borrar/'+id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.actives = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.todas = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras/todas',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.hoy = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras/hoy',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.cliente = function(id){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras/'+id+'/cliente',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve(data);
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.distribuidor = function(id){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras/'+id+'/distribuidor',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve(data);
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.dedistribuidor = function(id){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'bitacoras/'+id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve(data);
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};
})

.service('ReportedeIngresos', function($http, $q, ApiEndpoint){
	this.time = function(t){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/proyeccion/ano',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
		
	};

	this.fechaReportes = function(d){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/proyeccion/fecha/'+d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
		});
		console.log(d);
		console.log(dfd);
		return dfd.promise;
		
	};
})

.service('Reportes', function($http, $q, ApiEndpoint){
	this.get = function(){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'reportes/distribuidores/insolutos/html',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};
})

.service('Contratos', function($http, $q, ApiEndpoint){
	this.save = function(d){
		console.log(d);
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'distribuidor/'+d.id+'/new/contrato',
			data: d.d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			console.log("jalo")
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			console.log("nojalo")
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};

	this.search = function(product,page, query){
		if(typeof product === 'undefined'){
			product = 'all';
		}
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'contratos/' + product + '/' + page,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data: {
				query: query
			}
		})
		.success(function (data) {
			console.log("jalo")
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			console.log("nojalo")
			dfd.resolve(errorData);
		});
		return dfd.promise;
	}

	this.count = function(product, query){
		if(typeof product === 'undefined'){
			product = 'all';
		}
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'contratos/' + product + '/contar',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data: {
				query: query
			}
		})
		.success(function (data) {
			console.log("jalo")
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			console.log("nojalo")
			dfd.resolve(errorData);
		});
		return dfd.promise;
	}
})

.service('Pagos', function($http, $q, ApiEndpoint){
	this.count = function(parametros){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/log/contar',
			data: parametros,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.all = function(pagina,parametros){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/log/' + pagina,
			data: parametros,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.search = function(q, p){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'pagos/log/' + p,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : q
		})
		.success(function (data) {
            dfd.resolve({ status: 'ok', data: data });
        })
        .error(function (errorData) {
			dfd.resolve(errorData);
        });
        
        return dfd.promise;
	};

	this.history = function(distribuidor_id){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'pagos/log/distribuidor/' + distribuidor_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.autorizar = function(pago){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/autorizar/' + pago.pago_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.cancelar = function(pago){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/cancelar/' + pago.pago_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data: { motivo: pago.cancelacion_razon }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.saldo_afavor = function(distribuidor){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'pagos/' + distribuidor.distribuidor_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};
})

.service('Solicitudes', function($http, $q, ApiEndpoint){
	this.count = function(){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'solicitudes/count',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};

	this.getSolicitudes = function(s){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + 'solicitudes/' + s,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.getSolicitud = function(s){
		var dfd = $q.defer();
		
		$http({
			method: 'GET',
			url: ApiEndpoint.url  + 'solicitud/' + s,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.save = function(s){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'solicitud/new',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : s
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});

		return dfd.promise;
	};

	this.update = function(s, d){
		var dfd = $q.defer();
		console.log(s);
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'solicitud/' + s,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.cancelSolicitud = function(s){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + 'solicitud/cancelar/' + s,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.solicitudAnalizar= function(s){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + '/solicitud/analizar/' + s.solicitud_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : s
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.solicitudRechazar= function(s, r){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + '/solicitud/rechazar/' + s.solicitud_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : {r}
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.solicitudAprovar= function(s){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + '/solicitud/autorizar/' + s.solicitud_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : s
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};

	this.solicitudFormalizar= function(s){
		var dfd = $q.defer();
		
		$http({
			method: 'POST',
			url: ApiEndpoint.url  + '/solicitud/formalizar/' + s.solicitud_id,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : s
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		
		return dfd.promise;
	};
})

.service('Asuetos', function($http, $q, ApiEndpoint){
	this.get = function(){
		var dfd = $q.defer();
		$http({
			method: 'GET',
			url: ApiEndpoint.url + '/asuetos',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
			console.log(data);
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};
	this.new = function(d){
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'new/asueto',
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
			console.log(data);
		})	
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};
	this.update = function(d){
		console.log(d);
		var dfd = $q.defer();
		$http({
			method: 'POST',
			url: ApiEndpoint.url + 'asueto/'+d.id_asueto,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment },
			data : d
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
			console.log(data);
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};
	this.delete = function(d){
		var dfd = $q.defer();
		$http({
			method: 'DELETE',
			url: ApiEndpoint.url + 'delete/asueto/'+d,
			headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment }
		})
		.success(function (data) {
			dfd.resolve({ status: 'ok', data: data });
			console.log(data);
		})
		.error(function (errorData) {
			dfd.resolve(errorData);
		});
		return dfd.promise;
	};
})
;
